from setuptools import setup, find_packages

setup(
    name="stellvia",
    version="0.1.0",
    author="Bluelief",
    description="Python project.",
    license="MIT",
    keywords="python",
    packages=find_packages(),
    include_package_data=True,
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
    ],
)

